// WFProcess 流程模版基本信息
import { defHttp } from '@/utils/http/axios';
import {
  countItem,
  countModel,
  AccountParams,
  AddParams,
  countDetItem
} from './model/index';

enum Api {
  // 获取用地线分页列表
  LoadYongdixianPageList = '/api/TaxYongdixian/LoadYongdixianPageList',
  //  根据id获取单个用地线信息
  GetYongdixianInfoById = '/api/TaxYongdixian/GetYongdixianInfoById',
  //根据所属宗地编码获取用地线
  GetYongdixianInfoByBM = '/api/TaxYongdixian/GetYongdixianInfoByBM',
  // 新增
  AddYongdixian = '/api/TaxYongdixian/AddYongdixian',
  // 编辑
  UpdateYongdixian = '/api/TaxYongdixian/UpdateYongdixian',
  // 删除
  DeleteYongdixian = '/api/TaxYongdixian/DeleteYongdixian',
  // 获取用地点分页列表
  LoadYongdidianPageList = '/api/TaxYongdixian/LoadYongdidianPageList',
  //  根据id获取单个用地点信息
  GetYongdidianInfoById = '/api/TaxYongdixian/GetYongdidianInfoById',
  //根据所属宗地编码获取用地点
  GetYongdidianInfoByBM = '/api/TaxYongdixian/GetYongdidianInfoByBM',
  // 新增
  AddYongdidian = '/api/TaxYongdixian/AddYongdidian',
  // 编辑
  UpdateYongdidian = '/api/TaxYongdixian/UpdateYongdidian',
  // 删除
  DeleteYongdidian = '/api/TaxYongdixian/DeleteYongdidian',
}


/**
 * @description: getCaseFlowLog
 */
export function LoadYongdixianPageList(params?: AccountParams) {
  return defHttp.get<countModel>({ url: Api.LoadYongdixianPageList, params });
}
export function GetYongdixianInfoById(params?: countItem) {
  return defHttp.get<countModel>({ url: Api.GetYongdixianInfoById, params });
}
export function GetYongdixianInfoByBM(params?: AccountParams) {
  return defHttp.get<countModel>({ url: Api.GetYongdixianInfoByBM, params });
}
export function AddYongdixian(params?: AddParams) {
  return defHttp.post<countModel>({ url: Api.AddYongdixian, params });
}
export function UpdateYongdixian(params?: AddParams) {
  return defHttp.post<countModel>({ url: Api.UpdateYongdixian, params });
}
export function DeleteYongdixian(params?: countDetItem) {
  return defHttp.post<countModel>({ url: Api.DeleteYongdixian, params });
}

export function LoadYongdidianPageList(params?: AccountParams) {
  return defHttp.get<countModel>({ url: Api.LoadYongdidianPageList, params });
}
export function GetYongdidianInfoById(params?: countItem) {
  return defHttp.get<countModel>({ url: Api.GetYongdidianInfoById, params });
}
export function GetYongdidianInfoByBM(params?: AccountParams) {
  return defHttp.get<countModel>({ url: Api.GetYongdidianInfoByBM, params });
}
export function AddYongdidian(params?: AddParams) {
  return defHttp.post<countModel>({ url: Api.AddYongdidian, params });
}
export function UpdateYongdidian(params?: AddParams) {
  return defHttp.post<countModel>({ url: Api.UpdateYongdidian, params });
}
export function DeleteYongdidian(params?: countDetItem) {
  return defHttp.post<countModel>({ url: Api.DeleteYongdidian, params });
}
